@@ -345,13 +345,11 @@ module Gollum
       multi_commit = !!commit[:committer]
       committer    = multi_commit ? commit[:committer] : Committer.new(self, commit)
 
-      filename = Gollum::Page.cname(sanitized_name)
-
-      committer.add_to_index(sanitized_dir, filename, format, data)
+      committer.add_to_index(sanitized_dir, sanitized_name, format, data)
 
       committer.after_commit do |index, _sha|
         @access.refresh
-        index.update_working_dir(sanitized_dir, filename, format)
+        index.update_working_dir(sanitized_dir, sanitized_name, format)
       end
 
       multi_commit ? committer : committer.commit
@@ -444,7 +442,7 @@ module Gollum
       format ||= page.format
       dir      = ::File.dirname(page.path)
       dir      = '' if dir == '.'
-      filename = (rename = page.name != name) ? Gollum::Page.cname(name) : page.filename_stripped
+      filename = (rename = page.name != name) ? name.gsub(' ', '-') : page.filename_stripped
 
       multi_commit = !!commit[:committer]
       committer    = multi_commit ? commit[:committer] : Committer.new(self, commit)
